Learn R Programming

trustmebro (version 1.0.0)

inspect_numberid: Inspect if a number has the expected length

Description

Check whether a given numeric value has the expected number of digits.

Usage

inspect_numberid(number, expected_length)

Value

A logical value: `TRUE` if `number` has the expected length and consists only of digits, otherwise `FALSE`.

Arguments

number

A numeric value.

expected_length

An integer specifying the expected number of digits.

Examples

Run this code
inspect_numberid(12345, 5)  # TRUE - 5 digits
inspect_numberid(1234, 5)    # FALSE - 4 digits

Run the code above in your browser using DataLab