powered by
Check whether a given numeric value has the expected number of digits.
inspect_numberid(number, expected_length)
A logical value: `TRUE` if `number` has the expected length and consists only of digits, otherwise `FALSE`.
A numeric value.
An integer specifying the expected number of digits.
inspect_numberid(12345, 5) # TRUE - 5 digits inspect_numberid(1234, 5) # FALSE - 4 digits
Run the code above in your browser using DataLab